EXPORTS
	?Bind@RProcessRoot@@QAEXAAVTRequestStatus@@AAVTRSBindingInfo@RootServer@@@Z @ 1 NONAME ; void RProcessRoot::Bind(class TRequestStatus &, class RootServer::TRSBindingInfo &)
	?CancelBind@RProcessRoot@@QAEXAAVTRSSubModuleAddress@RootServer@@0@Z @ 2 NONAME ; void RProcessRoot::CancelBind(class RootServer::TRSSubModuleAddress &, class RootServer::TRSSubModuleAddress &)
	?CancelLoadModule@RProcessRoot@@QAEXABV?$TBuf8@$0CA@@@@Z @ 3 NONAME ; void RProcessRoot::CancelLoadModule(class TBuf8<32> const &)
	?CancelUnbind@RProcessRoot@@QAEXAAVTRSSubModuleAddress@RootServer@@0@Z @ 4 NONAME ; void RProcessRoot::CancelUnbind(class RootServer::TRSSubModuleAddress &, class RootServer::TRSSubModuleAddress &)
	?CancelUnloadModule@RProcessRoot@@QAEXABV?$TBuf8@$0CA@@@@Z @ 5 NONAME ; void RProcessRoot::CancelUnloadModule(class TBuf8<32> const &)
	?Close@RProcessRoot@@QAEXXZ @ 6 NONAME ; void RProcessRoot::Close(void)
	?Connect@RProcessRoot@@QAEHABVTDesC16@@@Z @ 7 NONAME ; int RProcessRoot::Connect(class TDesC16 const &)
	?EnumerateBindings@RProcessRoot@@QAEHABVTCFSubModuleAddress@CommsFW@@AAVTRSIter@RootServer@@AAVTRSBindingInfo@5@@Z @ 8 NONAME ; int RProcessRoot::EnumerateBindings(class CommsFW::TCFSubModuleAddress const &, class RootServer::TRSIter &, class RootServer::TRSBindingInfo &)
	?EnumerateModules@RProcessRoot@@QAEHAAVTRSIter@RootServer@@AAV?$TBuf8@$0CA@@@@Z @ 9 NONAME ; int RProcessRoot::EnumerateModules(class RootServer::TRSIter &, class TBuf8<32> &)
	?EnumerateSubModules@RProcessRoot@@QAEHABV?$TBuf8@$0CA@@@AAVTRSIter@RootServer@@AAV2@@Z @ 10 NONAME ; int RProcessRoot::EnumerateSubModules(class TBuf8<32> const &, class RootServer::TRSIter &, class TBuf8<32> &)
	?GetModuleInfo@RProcessRoot@@QAEHABV?$TBuf8@$0CA@@@AAVTRSModuleInfo@RootServer@@@Z @ 11 NONAME ; int RProcessRoot::GetModuleInfo(class TBuf8<32> const &, class RootServer::TRSModuleInfo &)
	?LoadModule@RProcessRoot@@QAEXAAVTRequestStatus@@ABVTRSStartModuleParams@RootServer@@ABVTDesC8@@@Z @ 12 NONAME ; void RProcessRoot::LoadModule(class TRequestStatus &, class RootServer::TRSStartModuleParams const &, class TDesC8 const &)
	?SendMessage@RProcessRoot@@QAEHABV?$TBuf8@$0CA@@@HAAVTDes8@@@Z @ 13 NONAME ; int RProcessRoot::SendMessage(class TBuf8<32> const &, int, class TDes8 &)
	?SendMessage@RProcessRoot@@QAEXAAVTRequestStatus@@ABV?$TBuf8@$0CA@@@HAAVTDes8@@@Z @ 14 NONAME ; void RProcessRoot::SendMessage(class TRequestStatus &, class TBuf8<32> const &, int, class TDes8 &)
	?Shutdown@RProcessRoot@@QAEHXZ @ 15 NONAME ; int RProcessRoot::Shutdown(void)
	?Unbind@RProcessRoot@@QAEXAAVTRequestStatus@@AAVTRSUnBindingInfo@RootServer@@@Z @ 16 NONAME ; void RProcessRoot::Unbind(class TRequestStatus &, class RootServer::TRSUnBindingInfo &)
	?UnloadModule@RProcessRoot@@QAEXAAVTRequestStatus@@ABV?$TBuf8@$0CA@@@W4TCFShutdownType@CommsFW@@@Z @ 17 NONAME ; void RProcessRoot::UnloadModule(class TRequestStatus &, class TBuf8<32> const &, enum CommsFW::TCFShutdownType)
	?Version@RProcessRoot@@QBE?AVTVersion@@XZ @ 18 NONAME ; class TVersion RProcessRoot::Version(void) const
	?__DbgCheckHeap@RProcessRootDbg@@AAEHH@Z @ 19 NONAME ; int RProcessRootDbg::__DbgCheckHeap(int)
	?__DbgFailNext@RProcessRootDbg@@AAEHH@Z @ 20 NONAME ; int RProcessRootDbg::__DbgFailNext(int)
	?__DbgMarkEnd@RProcessRootDbg@@AAEHH@Z @ 21 NONAME ; int RProcessRootDbg::__DbgMarkEnd(int)
	?__DbgMarkHeap@RProcessRootDbg@@AAEHXZ @ 22 NONAME ; int RProcessRootDbg::__DbgMarkHeap(void)


